<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="SN" prop="deviceNo">
        <el-input
          v-model="queryParams.deviceNo"
          placeholder="请输入设备SN"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="MAC" prop="likeAnyMac">
        <el-input
          v-model="queryParams.likeAnyMac"
          placeholder="请输入设备MAC-1或MAC-2"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="型号" prop="modelIds">
        <model-simple-select v-model="queryParams.modelIds" multiple @change="handleQuery" clearable/>
      </el-form-item>
      <el-form-item label="设备名称" prop="deviceName">
        <el-input
          v-model="queryParams.deviceName"
          placeholder="请输入设备名称"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="用户名称" prop="userName">
        <el-input
          v-model="queryParams.userName"
          placeholder="请输入所属用户名称"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="店铺名称" prop="storeName">
        <el-input
          v-model="queryParams.storeName"
          placeholder="请输入店铺名称"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="代理名称" prop="agentName">
        <el-input
          v-model="queryParams.agentName"
          placeholder="请输入代理名称"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="服务模式" prop="serviceMode">
        <el-select v-model="queryParams.serviceMode" placeholder="请选择服务模式" clearable @change="handleQuery">
          <el-option
            v-for="dict in dict.type.device_service_mode"
            :key="dict.value"
            :label="dict.label"
            :value="dict.value"
          />
        </el-select>
      </el-form-item>
      <el-form-item label="在线状态" prop="onlineStatus">
        <el-select v-model="queryParams.onlineStatus" placeholder="请选择在线状态" clearable @change="handleQuery">
          <el-option
            v-for="dict in dict.type.sm_device_online_status"
            :key="dict.value"
            :label="dict.label"
            :value="dict.value"
          />
        </el-select>
      </el-form-item>
      <el-form-item label="状态" prop="status">
        <el-select v-model="queryParams.status" placeholder="请选择状态" clearable @change="handleQuery">
          <el-option
            v-for="dict in dict.type.sm_device_status"
            :key="dict.value"
            :label="dict.label"
            :value="dict.value"
          />
        </el-select>
      </el-form-item>
      <el-form-item label="是否到期" prop="isArrears">
        <el-select v-model="queryParams.isArrears" placeholder="请选择是否到期" clearable @change="handleQuery">
          <el-option value="1" label="已到期"/>
          <el-option value="0" label="未到期"/>
        </el-select>
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['system:device:add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['system:device:remove']"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
          v-hasPermi="['system:device:export']"
        >导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <device-table :data="deviceList" :loading="loading" @selection-change="handleSelectionChange">
      <template v-slot:operate="scope">
        <el-button
          size="mini"
          type="text"
          icon="el-icon-view"
          @click="handleSee(scope.row)"
          v-hasPermi="['system:device:detail']"
        >详情</el-button>
        <el-button
          size="mini"
          type="text"
          icon="el-icon-refresh"
          @click="handleResetService(scope.row)"
          v-hasPermi="['system:device:edit']"
        >重置服务费</el-button>
        <el-button
          size="mini"
          type="text"
          icon="el-icon-edit"
          @click="handleUpdate(scope.row)"
          v-hasPermi="['system:device:edit']"
        >修改</el-button>
        <el-button
          size="mini"
          type="text"
          icon="el-icon-delete"
          @click="handleDelete(scope.row)"
          v-hasPermi="['system:device:remove']"
        >删除</el-button>
      </template>
    </device-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <sn-input :show.sync="showBindSn" @submit="onSubmitSn"></sn-input>

    <!-- 添加或修改设备对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="800px" append-to-body :close-on-click-modal="false">
      <el-form ref="form" :model="form" :rules="rules" label-width="6em">
        <el-row :gutter="gutter">
          <form-col :span="span"  label="自定义图片" prop="customPicture">
            <image-upload v-model="form.customPicture" :limit="1"/>
          </form-col>
          <form-col :span="span"  label="型号" prop="modelId">
            <model-select v-model="form.modelId" :show-value.sync="form.model" @submit="onSubmitModel"/>
          </form-col>
          <form-col :span="span"  label="MAC-1" prop="mac">
            <el-input v-model="form.mac" placeholder="请输入设备MAC-1" :disabled="isEdit"/>
          </form-col>
          <form-col :span="span"  label="MAC-2" prop="mac2">
            <el-input v-model="form.mac2" placeholder="请输入设备MAC-2" :disabled="isEdit"/>
          </form-col>
          <form-col :span="span"  label="SN" prop="deviceNo">
            <el-input v-model="form.deviceNo" placeholder="请输入设备SN" />
          </form-col>
          <form-col :span="span"  label="名称" prop="deviceName">
            <el-input v-model="form.deviceName" placeholder="请输入设备名称" />
          </form-col>
          <form-col :span="span * 2" label="备注" prop="remark">
            <el-input v-model="form.remark" type="textarea" placeholder="请输入备注" maxlength="500" show-word-limit/>
          </form-col>
          <form-col :span="span" label="设备月费" prop="monthFee">
            <el-input v-model="form.monthFee" placeholder="请输入月费" type="number" :min="0">
              <template #append>
                元 / 月
              </template>
            </el-input>
          </form-col>
          <form-col :span="span" label="服务模式" prop="serviceMode">
            <el-radio-group v-model="form.serviceMode">
              <el-radio v-for="item of dict.type.device_service_mode" :label="item.value" :key="item.value">{{item.label}}</el-radio>
            </el-radio-group>
          </form-col>
          <template v-if="form.serviceMode === DeviceServiceMode.AGENT">
            <form-col :span="span" label="代理商" prop="agentId">
              <user-input v-model="form.agentId" :query="{type: SmUserType.AGENT}" />
            </form-col>
            <form-col :span="span" label="代理服务费" prop="agentServiceRate" label-width="7em">
              <el-input v-model="form.agentServiceRate" placeholder="请输入代理服务费" type="number">
                <template #append>%</template>
              </el-input>
            </form-col>
          </template>
          <template v-else>
            <form-col :span="span" label="服务费" prop="serviceRate">
              <el-input v-model="form.serviceRate" placeholder="请输入服务费" type="number">
                <template #append>%</template>
              </el-input>
            </form-col>
          </template>
        </el-row>
        <el-row :gutter="gutter">
          <form-col :span="10" label="限制充值至" prop="limitRechargeTime">
            <el-date-picker type="datetime" v-model="form.limitRechargeTime" placeholder="请选择限制充值时间" value-format="yyyy-MM-dd HH:mm:ss" :clearable="false"/>
          </form-col>
          <form-col :span="14" label="限制充值原因" prop="limitRechargeReason" label-width="7em">
            <el-input v-model="form.limitRechargeReason" type="textarea" placeholder="请输入限制充值的原因（展示给用户查看）" show-word-limit maxlength="200"/>
          </form-col>
        </el-row>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>

    <!--型号选择弹窗-->
    <model-dialog
      :show.sync="showCheckModel"
      @select="onSubmitBatchModel"
    />

  </div>
</template>

<script>
import {
  listDevice,
  getDevice,
  addDevice,
  updateDevice,
  logicDelDevice,
  updateDeviceSn,
  batchUpdateModel, updateDeviceServiceRate
} from '@/api/system/device'
import ModelSelect from "@/components/Business/Model/modelSelect.vue";
import SmUserSelect from "@/components/Business/SmUser/smUserSelect.vue";
import QrCode from "@/components/QrCode/index.vue";
import {getWxIndexUrl} from "@/utils/wx";
import SnInput from '@/components/SnInput/index.vue'
import StoreInput from '@/components/Business/Store/StoreInput.vue'
import UserInput from '@/components/Business/SmUser/UserInput.vue'
import { isEmpty } from '@/utils'
import ModelDialog from '@/components/Business/Model/modelDialog.vue'
import UserLink from '@/components/Business/SmUser/UserLink.vue'
import StoreLink from '@/components/Business/Store/StoreLink.vue'
import DeviceLink from '@/components/Business/Device/DeviceLink.vue'
import { $serviceType, $view } from '@/utils/mixins'
import ModelSimpleSelect from '@/components/Business/Model/ModelSimpleSelect.vue'
import { DeviceServiceMode, SmUserType } from '@/utils/constants'
import DeviceTable from '@/views/system/device/components/DeviceTable.vue'

export default {
  name: "Device",
  mixins: [$serviceType, $view],
  components: { DeviceTable, ModelSimpleSelect, DeviceLink, StoreLink, UserLink, ModelDialog, UserInput, StoreInput, SnInput, QrCode, SmUserSelect, ModelSelect},
  dicts: ['sm_device_online_status', 'sm_device_status', 'sm_device_outage_way','sm_device_notice_way', 'service_type', 'time_unit', 'device_service_mode'],
  props: {
    query: {
      type: Object,
      default: () => {
        return {}
      }
    }
  },
  data() {
    return {
      // 是否展示选择型号弹窗
      showCheckModel: false,
      span: 12,
      gutter: 8,
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 设备表格数据
      deviceList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 20,
        orderByColumn: "createTime",
        isAsc: "desc",
        storeName: null,
        deviceName: null,
        model: null,
        mac: null,
        deviceNo: null,
        onlineStatus: null,
        status: null,
        userName: null,
        tenantName: null,
        isArrears: null,
        modelIds: []
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        modelId: [
          { required: true, message: "型号不能为空", trigger: "change" }
        ],
        mac: [
          { required: true, message: "设备MAC不能为空", trigger: "change" }
        ],
        serviceMode: [
          { required: true, message: "服务模式不能为空", trigger: "change" }
        ],
        agentId: [
          { required: true, message: "代理商不能为空", trigger: "change" }
        ],
        agentServiceRate: [
          { required: true, message: "代理商服务费率不能为空", trigger: "blur" }
        ]
      },
      // 房租提醒日期选项配置
      expireDatePickerOptions: {
        disabledDate(date) {
          return date.getTime() <= Date.now();
        }
      },
      showBindSn: false,
      snLoading: false,
    };
  },
  computed: {
    DeviceServiceMode() {
      return DeviceServiceMode
    },
    SmUserType() {
      return SmUserType
    },
    isEdit() {
      return this.title === "修改设备";
    },
  },
  created() {
    this.queryParams = {
      ...this.queryParams,
      ...this.query,
      ...this.$route.query
    }

    if (this.view != null) {
      this.showSearch = false;
    }

    this.getList();
  },
  methods: {
    // 选中型号后
    onSubmitBatchModel(model) {
      if (model == null) {
        return;
      }
      batchUpdateModel(this.ids, model.modelId).then(res => {
        if (res.code === 200) {
          this.$message.success("操作成功");
          this.showCheckModel = false;
          this.getList();
        }
      })
    },
    isEmpty,
    // 绑定SN
    onSubmitSn(data) {
      this.snLoading = true;
      updateDeviceSn(this.form.deviceId, data.sn).then(res => {
        if (res.code !== 200) {
          return this.$message.error(res.msg);
        }
        this.$message.success("操作成功");
        this.showBindSn = false;
        this.getList();
      }).finally(()=> {
        this.snLoading = false;
      })
    },
    // 选中店铺后
    onSubmitGroup(group) {
      this.form.groupId = group?.groupId;
      this.form.groupName = group?.groupName;
    },
    // 选中型号后
    onSubmitModel(model) {
      this.form.model = model?.modelName;
      // 若是新增，则填入默认的服务费
      if (this.form.deviceId == null) {
        this.form.serviceType = model?.serviceType;
        this.form.serviceRate = model?.serviceRate;
      }
    },
    /** 查询设备列表 */
    getList() {
      this.loading = true;
      listDevice(this.queryParams).then(response => {
        this.deviceList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        deviceId: null,
        picture: null,
        modelId: null,
        mac: null,
        deviceNo: null,
        deviceName: null,
        serviceType: '1',
        serviceRate: null,
        remark: null,
        startTime: null,
        startUnit: "3",
        startPrice: null,
        overTime: null,
        overUnit: "3",
        overPrice: null,
        serviceMode: '1'
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.deviceId)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    // 查看按钮操作
    handleSee(row) {
      this.$router.push({path: `/smDevice/device/${row.deviceId}`})
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加设备";
    },
    // 重置服务费
    handleResetService(row) {
      this.$confirm(`确定重置设备${row.deviceNo}的服务费吗？`, '重置服务费', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(() => {
        this.loading = true;
        updateDeviceServiceRate(row.deviceId, null).then(res => {
          if (res.code === 200) {
            this.$message.success("重置成功")
          }
        }).finally(() => {
          this.getList();
        })
      })
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const deviceId = row.deviceId || this.ids
      getDevice(deviceId).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改设备";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.deviceId != null) {
            updateDevice(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addDevice(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    handleBatchModel() {
      this.showCheckModel = true;
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const deviceIds = row.deviceId || this.ids;
      this.$modal.confirm('是否确认删除设备编号为"' + deviceIds + '"的数据项？').then(function() {
        return logicDelDevice(deviceIds);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('system/device/export', {
        ...this.queryParams
      }, `device_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
